@@ -1,5 +1,5 @@
 from .schema import *
-from .feedforward import *
 from .token_mixers import *
+from .channel_mixers import *
 from .poolers import *
 from .api import *
